Crate local_issues_lib

Crate local_issues_lib 

This crate provides a simple library for managing local issues and users.

Modules

user
Module for user-related functionality. This module provides functionality for managing users in the local issues system.

Structs

Comment
Represents a comment entry associated with an issue.
Issue
Represents a single issue.
Issues
A collection of issues.

Enums

Status
Represents the status of an issue.